@@ -10,8 +10,8 @@ class MarketCategory(BaseCategory):
         name: str,
         description: str,
         category_id: int,
-        price: typing.Optional[int] = None,
-        old_price: typing.Optional[int] = None,
+        price: typing.Optional[float] = None,
+        old_price: typing.Optional[float] = None,
         deleted: typing.Optional[bool] = None,
         main_photo_id: typing.Optional[int] = None,
         photo_ids: typing.Optional[typing.List[int]] = None,
@@ -52,6 +52,7 @@ class MarketCategory(BaseCategory):
         title: str,
         photo_id: typing.Optional[int] = None,
         main_album: typing.Optional[bool] = None,
+        is_hidden: typing.Optional[bool] = None,
         **kwargs
     ) -> market.AddAlbumResponseModel:
         """Creates new collection of items
@@ -59,6 +60,7 @@ class MarketCategory(BaseCategory):
         :param title: Collection title.
         :param photo_id: Cover photo ID.
         :param main_album: Set as main ('1' - set, '0' - no).
+        :param is_hidden: Set as hidden
         """
 
         params = self.get_set_params(locals())
@@ -67,11 +69,15 @@ class MarketCategory(BaseCategory):
         return model(**response).response
 
     async def add_to_album(
-        self, owner_id: int, item_id: int, album_ids: typing.List[int], **kwargs
-    ) -> base.OkResponseModel:
+        self,
+        owner_id: int,
+        item_ids: typing.List[int],
+        album_ids: typing.List[int],
+        **kwargs
+    ) -> int:
         """Adds an item to one or multiple collections.
         :param owner_id: ID of an item owner community.
-        :param item_id: Item ID.
+        :param item_ids:
         :param album_ids: Collections IDs to add item to.
         """
 
@@ -91,7 +97,7 @@ class MarketCategory(BaseCategory):
         sticker_id: typing.Optional[int] = None,
         guid: typing.Optional[str] = None,
         **kwargs
-    ) -> market.CreateCommentResponseModel:
+    ) -> int:
         """Creates a new comment for an item.
         :param owner_id: ID of an item owner community.
         :param item_id: Item ID.
@@ -110,7 +116,7 @@ class MarketCategory(BaseCategory):
 
     async def delete(
         self, owner_id: int, item_id: int, **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Deletes an item.
         :param owner_id: ID of an item owner community.
         :param item_id: Item ID.
@@ -123,7 +129,7 @@ class MarketCategory(BaseCategory):
 
     async def delete_album(
         self, owner_id: int, album_id: int, **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Deletes a collection of items.
         :param owner_id: ID of an collection owner community.
         :param album_id: Collection ID.
@@ -136,7 +142,7 @@ class MarketCategory(BaseCategory):
 
     async def delete_comment(
         self, owner_id: int, comment_id: int, **kwargs
-    ) -> market.DeleteCommentResponseModel:
+    ) -> market.BaseBoolInt:
         """Deletes an item's comment
         :param owner_id: identifier of an item owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
         :param comment_id: comment id
@@ -154,13 +160,13 @@ class MarketCategory(BaseCategory):
         name: str,
         description: str,
         category_id: int,
-        price: typing.Optional[int] = None,
+        price: typing.Optional[float] = None,
         deleted: typing.Optional[bool] = None,
         main_photo_id: typing.Optional[int] = None,
         photo_ids: typing.Optional[typing.List[int]] = None,
         url: typing.Optional[str] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Edits an item.
         :param owner_id: ID of an item owner community.
         :param item_id: Item ID.
@@ -186,14 +192,16 @@ class MarketCategory(BaseCategory):
         title: str,
         photo_id: typing.Optional[int] = None,
         main_album: typing.Optional[bool] = None,
+        is_hidden: typing.Optional[bool] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Edits a collection of items
         :param owner_id: ID of an collection owner community.
         :param album_id: Collection ID.
         :param title: Collection title.
         :param photo_id: Cover photo id
         :param main_album: Set as main ('1' - set, '0' - no).
+        :param is_hidden: Set as hidden
         """
 
         params = self.get_set_params(locals())
@@ -208,7 +216,7 @@ class MarketCategory(BaseCategory):
         message: typing.Optional[str] = None,
         attachments: typing.Optional[typing.List[str]] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Chages item comment's text
         :param owner_id: ID of an item owner community.
         :param comment_id: Comment ID.
@@ -235,7 +243,7 @@ class MarketCategory(BaseCategory):
         height: typing.Optional[int] = None,
         weight: typing.Optional[int] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Edit order
         :param user_id:
         :param order_id:
@@ -264,6 +272,8 @@ class MarketCategory(BaseCategory):
         extended: typing.Optional[bool] = None,
         date_from: typing.Optional[str] = None,
         date_to: typing.Optional[str] = None,
+        need_variants: typing.Optional[bool] = None,
+        with_disabled: typing.Optional[bool] = None,
         **kwargs
     ) -> market.GetResponseModel:
         """Returns items list for a community.
@@ -274,6 +284,8 @@ class MarketCategory(BaseCategory):
         :param extended: '1' - method will return additional fields: 'likes, can_comment, car_repost, photos'. These parameters are not returned by default.
         :param date_from: Items update date from (format: yyyy-mm-dd)
         :param date_to: Items update date to (format: yyyy-mm-dd)
+        :param need_variants: Add variants to response if exist
+        :param with_disabled: Add disabled items to response
         """
 
         params = self.get_set_params(locals())
@@ -466,7 +478,7 @@ class MarketCategory(BaseCategory):
 
     async def remove_from_album(
         self, owner_id: int, item_id: int, album_ids: typing.List[int], **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Removes an item from one or multiple collections.
         :param owner_id: ID of an item owner community.
         :param item_id: Item ID.
@@ -485,7 +497,7 @@ class MarketCategory(BaseCategory):
         before: typing.Optional[int] = None,
         after: typing.Optional[int] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Reorders the collections list.
         :param owner_id: ID of an item owner community.
         :param album_id: Collection ID.
@@ -506,7 +518,7 @@ class MarketCategory(BaseCategory):
         before: typing.Optional[int] = None,
         after: typing.Optional[int] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Changes item place in a collection.
         :param owner_id: ID of an item owner community.
         :param item_id: Item ID.
@@ -526,7 +538,7 @@ class MarketCategory(BaseCategory):
         item_id: int,
         reason: typing.Optional[int] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Sends a complaint to the item.
         :param owner_id: ID of an item owner community.
         :param item_id: Item ID.
@@ -540,7 +552,7 @@ class MarketCategory(BaseCategory):
 
     async def report_comment(
         self, owner_id: int, comment_id: int, reason: int, **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Sends a complaint to the item's comment.
         :param owner_id: ID of an item owner community.
         :param comment_id: Comment ID.
@@ -554,7 +566,7 @@ class MarketCategory(BaseCategory):
 
     async def restore(
         self, owner_id: int, item_id: int, **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Restores recently deleted item
         :param owner_id: ID of an item owner community.
         :param item_id: Deleted item ID.
@@ -567,7 +579,7 @@ class MarketCategory(BaseCategory):
 
     async def restore_comment(
         self, owner_id: int, comment_id: int, **kwargs
-    ) -> market.RestoreCommentResponseModel:
+    ) -> market.BaseBoolInt:
         """Restores a recently deleted comment
         :param owner_id: identifier of an item owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
         :param comment_id: deleted comment id
@@ -591,6 +603,7 @@ class MarketCategory(BaseCategory):
         count: typing.Optional[int] = None,
         extended: typing.Optional[bool] = None,
         status: typing.Optional[int] = None,
+        need_variants: typing.Optional[bool] = None,
         **kwargs
     ) -> market.SearchResponseModel:
         """Searches market items in a community's catalog
@@ -605,6 +618,7 @@ class MarketCategory(BaseCategory):
         :param count: Number of items to return.
         :param extended: '1' - to return additional fields: 'likes, can_comment, car_repost, photos'. By default: '0'.
         :param status:
+        :param need_variants: Add variants to response if exist
         """
 
         params = self.get_set_params(locals())
