@@ -9,7 +9,7 @@ class StatusCategory(BaseCategory):
         user_id: typing.Optional[int] = None,
         group_id: typing.Optional[int] = None,
         **kwargs
-    ) -> status.GetResponseModel:
+    ) -> status.StatusStatus:
         """Returns data required to show the status of a user or community.
         :param user_id: User ID or community ID. Use a negative value to designate a community ID.
         :param group_id:
@@ -25,7 +25,7 @@ class StatusCategory(BaseCategory):
         text: typing.Optional[str] = None,
         group_id: typing.Optional[int] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Sets a new status for the current user.
         :param text: Text of the new status.
         :param group_id: Identifier of a community to set a status in. If left blank the status is set to current user.
