@@ -6,7 +6,7 @@ from vkbottle_types.responses import base, wall
 class WallCategory(BaseCategory):
     async def check_copyright_link(
         self, link: str, **kwargs
-    ) -> base.BoolResponseModel:
+    ) -> base.BaseBoolInt:
         """wall.checkCopyrightLink method
         :param link:
         """
@@ -18,7 +18,7 @@ class WallCategory(BaseCategory):
 
     async def close_comments(
         self, owner_id: int, post_id: int, **kwargs
-    ) -> base.BoolResponseModel:
+    ) -> base.BaseBoolInt:
         """wall.closeComments method
         :param owner_id:
         :param post_id:
@@ -62,7 +62,7 @@ class WallCategory(BaseCategory):
         owner_id: typing.Optional[int] = None,
         post_id: typing.Optional[int] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Deletes a post from a user wall or community wall.
         :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
         :param post_id: ID of the post to be deleted.
@@ -75,7 +75,7 @@ class WallCategory(BaseCategory):
 
     async def delete_comment(
         self, comment_id: int, owner_id: typing.Optional[int] = None, **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Deletes a comment on a post on a user wall or community wall.
         :param comment_id: Comment ID.
         :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
@@ -96,8 +96,8 @@ class WallCategory(BaseCategory):
         services: typing.Optional[str] = None,
         signed: typing.Optional[bool] = None,
         publish_date: typing.Optional[int] = None,
-        lat: typing.Optional[int] = None,
-        long: typing.Optional[int] = None,
+        lat: typing.Optional[float] = None,
+        long: typing.Optional[float] = None,
         place_id: typing.Optional[int] = None,
         mark_as_ads: typing.Optional[bool] = None,
         close_comments: typing.Optional[bool] = None,
@@ -106,6 +106,7 @@ class WallCategory(BaseCategory):
         poster_bkg_owner_id: typing.Optional[int] = None,
         poster_bkg_access_hash: typing.Optional[str] = None,
         copyright: typing.Optional[str] = None,
+        topic_id: typing.Optional[int] = None,
         **kwargs
     ) -> wall.EditResponseModel:
         """Edits a post on a user wall or community wall.
@@ -127,6 +128,7 @@ class WallCategory(BaseCategory):
         :param poster_bkg_owner_id:
         :param poster_bkg_access_hash:
         :param copyright:
+        :param topic_id: Topic ID. Allowed values can be obtained from newsfeed.getPostTopics method
         """
 
         params = self.get_set_params(locals())
@@ -141,15 +143,15 @@ class WallCategory(BaseCategory):
         message: typing.Optional[str] = None,
         attachments: typing.Optional[typing.List[str]] = None,
         signed: typing.Optional[bool] = None,
-        lat: typing.Optional[int] = None,
-        long: typing.Optional[int] = None,
+        lat: typing.Optional[float] = None,
+        long: typing.Optional[float] = None,
         place_id: typing.Optional[int] = None,
         link_button: typing.Optional[str] = None,
         link_title: typing.Optional[str] = None,
         link_image: typing.Optional[str] = None,
         link_video: typing.Optional[str] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Allows to edit hidden post.
         :param post_id: Post ID. Used for publishing of scheduled and suggested posts.
         :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
@@ -177,7 +179,7 @@ class WallCategory(BaseCategory):
         message: typing.Optional[str] = None,
         attachments: typing.Optional[typing.List[str]] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Edits a comment on a user wall or community wall.
         :param comment_id: Comment ID.
         :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
@@ -227,7 +229,7 @@ class WallCategory(BaseCategory):
         copy_history_depth: typing.Optional[int] = None,
         fields: typing.Optional[typing.List[str]] = None,
         **kwargs
-    ) -> wall.GetByIdLegacyResponseModel:
+    ) -> typing.List[wall.WallWallpostFull]:
         """Returns a list of posts from user or community walls by their IDs.
         :param posts: User or community IDs and post IDs, separated by underscores. Use a negative value to designate a community ID. Example: "93388_21539,93388_20904,2943_4276,-1_1"
         :param extended: '1' — to return user and community objects needed to display posts, '0' — no additional fields are returned (default)
@@ -330,7 +332,7 @@ class WallCategory(BaseCategory):
 
     async def open_comments(
         self, owner_id: int, post_id: int, **kwargs
-    ) -> base.BoolResponseModel:
+    ) -> base.BaseBoolInt:
         """wall.openComments method
         :param owner_id:
         :param post_id:
@@ -343,7 +345,7 @@ class WallCategory(BaseCategory):
 
     async def pin(
         self, post_id: int, owner_id: typing.Optional[int] = None, **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Pins the post on wall.
         :param post_id: Post ID.
         :param owner_id: ID of the user or community that owns the wall. By default, current user ID. Use a negative value to designate a community ID.
@@ -364,8 +366,8 @@ class WallCategory(BaseCategory):
         services: typing.Optional[str] = None,
         signed: typing.Optional[bool] = None,
         publish_date: typing.Optional[int] = None,
-        lat: typing.Optional[int] = None,
-        long: typing.Optional[int] = None,
+        lat: typing.Optional[float] = None,
+        long: typing.Optional[float] = None,
         place_id: typing.Optional[int] = None,
         post_id: typing.Optional[int] = None,
         guid: typing.Optional[str] = None,
@@ -374,6 +376,7 @@ class WallCategory(BaseCategory):
         donut_paid_duration: typing.Optional[int] = None,
         mute_notifications: typing.Optional[bool] = None,
         copyright: typing.Optional[str] = None,
+        topic_id: typing.Optional[int] = None,
         **kwargs
     ) -> wall.PostResponseModel:
         """Adds a new post on a user wall or community wall. Can also be used to publish suggested or scheduled posts.
@@ -395,6 +398,7 @@ class WallCategory(BaseCategory):
         :param donut_paid_duration:
         :param mute_notifications:
         :param copyright:
+        :param topic_id: Topic ID. Allowed values can be obtained from newsfeed.getPostTopics method
         """
 
         params = self.get_set_params(locals())
@@ -408,8 +412,8 @@ class WallCategory(BaseCategory):
         message: typing.Optional[str] = None,
         attachments: typing.Optional[typing.List[str]] = None,
         signed: typing.Optional[bool] = None,
-        lat: typing.Optional[int] = None,
-        long: typing.Optional[int] = None,
+        lat: typing.Optional[float] = None,
+        long: typing.Optional[float] = None,
         place_id: typing.Optional[int] = None,
         guid: typing.Optional[str] = None,
         link_button: typing.Optional[str] = None,
@@ -444,7 +448,7 @@ class WallCategory(BaseCategory):
         comment_id: int,
         reason: typing.Optional[int] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Reports (submits a complaint about) a comment on a post on a user wall or community wall.
         :param owner_id: ID of the user or community that owns the wall.
         :param comment_id: Comment ID.
@@ -462,7 +466,7 @@ class WallCategory(BaseCategory):
         post_id: int,
         reason: typing.Optional[int] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Reports (submits a complaint about) a post on a user wall or community wall.
         :param owner_id: ID of the user or community that owns the wall.
         :param post_id: Post ID.
@@ -501,7 +505,7 @@ class WallCategory(BaseCategory):
         owner_id: typing.Optional[int] = None,
         post_id: typing.Optional[int] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Restores a post deleted from a user wall or community wall.
         :param owner_id: User ID or community ID from whose wall the post was deleted. Use a negative value to designate a community ID.
         :param post_id: ID of the post to be restored.
@@ -514,7 +518,7 @@ class WallCategory(BaseCategory):
 
     async def restore_comment(
         self, comment_id: int, owner_id: typing.Optional[int] = None, **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Restores a comment deleted from a user wall or community wall.
         :param comment_id: Comment ID.
         :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
@@ -559,7 +563,7 @@ class WallCategory(BaseCategory):
 
     async def unpin(
         self, post_id: int, owner_id: typing.Optional[int] = None, **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Unpins the post on wall.
         :param post_id: Post ID.
         :param owner_id: ID of the user or community that owns the wall. By default, current user ID. Use a negative value to designate a community ID.
